using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Android.App;
using Android.Content;
using Android.OS;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using Android.Graphics;
using Android.Util;

using Com.GrapeCity.Xuni.FlexGrid;

namespace FlexGridSample
{
	public class CustomCellFactory : GridCellFactory
	{
		private ImageView image;
		private GridRow editRow;


		private int mCellWidth = 0;
		private int mCellHeight = 0;

		private int mPaddingLeft;
		private int mPaddingTop;

		public CustomCellFactory(FlexGrid flexGrid, Context  context)
			: base(flexGrid)
		{
			image = new ImageView (context);
			mPaddingLeft = (int)Math.Round(FlexGridCanvasRenderEngine.GetDimensionSize(flexGrid.CellPaddingLeft));
			mPaddingTop = (int)Math.Round(FlexGridCanvasRenderEngine.GetDimensionSize(flexGrid.CellPaddingTop));
			flexGrid.AddView (image);
			image.LayoutParameters.Height = 0;
			image.LayoutParameters.Width = 0;
		}

		public override void CreateCellContent(GridPanel gridPanel, FlexGridCanvasRenderEngine renderEngine, GridCellRange cellRange, Rect bounds)
		{
			if (gridPanel.CellType == GridCellType.Cell)
			{
				GridColumn column = gridPanel.Columns.Get(cellRange.Col).JavaCast<GridColumn>();
				GridRow row = (GridRow)gridPanel.Rows.Get (cellRange.Row).JavaCast<GridRow> ();

				Customer _customer = (Customer)row.DataItem;
				if (column != null && column.Name == "Money") {
					if (_customer.Money >= 80) {
						renderEngine.SetFillColor (Color.Green);
					} else {
						renderEngine.SetFillColor (Color.Blue);
					}
					base.CreateCellContent (gridPanel, renderEngine, cellRange, bounds);
				} 
				else if (column.Name == "Country") {
					if (bounds.Width () != mCellWidth && bounds.Height () != mCellHeight) {
						this.mCellWidth = bounds.Width ();
						this.mCellHeight = bounds.Height ();
						image.LayoutParameters.Height = mCellHeight - (mPaddingTop * 2);
						image.LayoutParameters.Width = mCellWidth - (mPaddingLeft * 2);
					}
					if (_customer.Country == "US") {
						image.SetImageResource (Resource.Drawable.US);
					}else if (_customer.Country == "UK") {
						image.SetImageResource (Resource.Drawable.UK);
					}else if (_customer.Country == "Japan") {
						image.SetImageResource (Resource.Drawable.Japan);
					}else if (_customer.Country == "Italy") {
						image.SetImageResource (Resource.Drawable.Italy);
					}else if (_customer.Country == "Greece") {
						image.SetImageResource (Resource.Drawable.Greece);
					}else if (_customer.Country == "Germany") {
						image.SetImageResource (Resource.Drawable.Germany);
					}

					renderEngine.Canvas.Save ();
					renderEngine.Canvas.Translate (bounds.Left + renderEngine.PanX + mPaddingLeft, bounds.Top + renderEngine.PanY + mPaddingTop);
					image.Draw (renderEngine.Canvas);
					renderEngine.Canvas.Restore ();

				}
				else {
					base.CreateCellContent(gridPanel, renderEngine, cellRange, bounds);
				}
			}
			else {
				base.CreateCellContent(gridPanel, renderEngine, cellRange, bounds);

			}
		}

		public override View CreateCellEditor(GridPanel gridPanel, GridCellRange cellRange, Rect bounds)
		{
			if (gridPanel.CellType == GridCellType.Cell)
			{
				GridColumn column = gridPanel.Columns.Get(cellRange.Col).JavaCast<GridColumn>();

				if (column != null && column.Name == "Hired")
				{
					GridRow row = (GridRow)gridPanel.Rows.Get(cellRange.Row).JavaCast<GridRow>();
					editRow = (GridRow)base.FlexGrid.Rows.Get(base.FlexGrid.EditRange.Row).JavaCast<GridRow>();
					Customer customer = (Customer)row.DataItem;

					Dialog dialog = new DatePickerDialog(FlexGrid.Context, OnDateSet, customer.Hired.Year, customer.Hired.Month - 1, customer.Hired.Day);

					dialog.Show();

					return null;
				}
			}

			return base.CreateCellEditor(gridPanel, cellRange, bounds);
		}

		void OnDateSet(object sender, DatePickerDialog.DateSetEventArgs e)
		{

			Customer customer = (Customer)editRow.DataItem;

			customer.Hired = e.Date;

			FlexGrid.FinishEditing(false);
			FlexGrid.Refresh(false);
		}
	}
}